MethodChannelFlutterZalo class

An implementation of FlutterZaloAPI that uses method channels.

Inheritance

Constructors

MethodChannelFlutterZalo()
Constructs a MethodChannelFlutterZalo.

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccessToken() Future<String?>
Retrieves the access token from the native platform.
override
getProfile() Future<Map<String, dynamic>?>
Retrieves the user profile from the native platform.
override
init() Future<void>
Initializes the plugin platform implementation.
override
isAccessTokenValid() Future<bool?>
Validates the current access token on the native platform.
override
logIn() Future<bool?>
Initiates the login flow on the native platform.
override
logOut() Future<bool?>
Logs out the user on the native platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshAccessToken() Future<bool?>
Requests the native platform to refresh the access token.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited