FlutterZaloAPI class abstract
The interface that platform-specific implementations of flutter_zalo must extend.
- Implementers
Constructors
- FlutterZaloAPI()
- Constructs a FlutterZaloAPI.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAccessToken(
) → Future< String?> - Retrieves the access token from the native platform.
-
getProfile(
) → Future< Map< String, dynamic> ?> - Retrieves the user profile from the native platform.
-
init(
) → Future< void> - Initializes the plugin platform implementation.
-
isAccessTokenValid(
) → Future< bool?> - Validates the current access token on the native platform.
-
logIn(
) → Future< bool?> - Initiates the login flow on the native platform.
-
logOut(
) → Future< bool?> - Logs out the user on the native platform.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshAccessToken(
) → Future< bool?> - Requests the native platform to refresh the access token.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterZaloAPI
-
The default instance of FlutterZaloAPI to use.
getter/setter pair